@@ -64,3 +64,12 @@ test_that(
     expect_true(expected == obtained)
   }
 )
+
+test_that(
+  "ZonalQCPP is correct", {
+    x <- as.bigq(c(6L,-7L,8L,9L), c(1L,2L,3L,4L))
+    lambda <- c(3, 2)
+    res <- ZonalQCPP(x, lambda)
+    expect_identical(res, ZonalQ(x, lambda))
+  }
+)
